@@ -962,3 +962,23 @@ class DXFile(DXDataObject):
         if self._binary_mode is True:
             return data
         return data.decode("utf-8")
+    
+    def archive(self, all_copies=False):
+        '''
+        :param all_copies: Force the transition of files into the archived state. Requesting user must be the ADMIN of the project billTo org. 
+            If true, archive all the copies of files in projects with the same billTo org.
+        :type all_copies: boolean
+        :raises: :exc:`~dxpy.exceptions.InvalidState` if the file is not in a live state
+        :raises: :exc:`~dxpy.exceptions.PermissionDenied` if the requesting user does not have CONTRIBUTE access or
+            is not an ADMIN of the project billTo org with allCopies=True.
+        '''
+        dxpy.api.project_archive(self.get_proj_id(), {"files": [self.get_id()], "allCopies": all_copies})
+
+    def unarchive(self, dry_run=False):
+        '''
+        :param dry_run:  If true, only display the output of the API call without executing the unarchival
+        :type dry_run: boolean
+        :raises: :exc:`~dxpy.exceptions.InvalidState` if the file is not in a closed or archived state
+        :raises: :exc:`~dxpy.exceptions.PermissionDenied` if the requesting user does not have CONTRIBUTE access    
+        '''
+        dxpy.api.project_unarchive(self.get_proj_id(), {"files": [self.get_id()], "dryRun": dry_run})
