@@ -40,7 +40,10 @@ completer_state = {
 }
 
 try:
-    import readline
+    try:
+        import gnureadline as readline
+    except ImportError:
+        import readline
     import rlcompleter
     readline.parse_and_bind("tab: complete")
     readline.set_completer_delims("")
@@ -285,7 +288,7 @@ def create_files_from_templates(template_dir, app_json, language,
 
     if os.path.exists(os.path.join(template_dir, 'test')):
         for template_filename in os.listdir(os.path.join(template_dir, 'test')):
-            if any(template_filename.endswith(ext) for ext in ('~', '.pyc', '.pyo')):
+            if any(template_filename.endswith(ext) for ext in ('~', '.pyc', '.pyo', '__pycache__')):
                 continue
             use_template_file(os.path.join('test', template_filename))
 
